###############################################################################
# Coscine Python Client
# Copyright (c) 2018-2021 RWTH Aachen University
# Contact: coscine@itc.rwth-aachen.de
# Git: https://git.rwth-aachen.de/coscine/docs/public/coscine-python-client
# Please direct bug reports, feature requests or questions at the URL above
# by opening an issue.
###############################################################################
# Coscine is an open source project at RWTH Aachen University for
# the management of research data.
# Visit https://coscine.de for more information.
###############################################################################

#
# This file shall demonstrate all functionality offered by the module in
# no specific order. Exceptions shall be handled where exception handling
# is necessary.
#

import json
import coscine

def token(filename):
	fd = open(filename, "rt")
	token = fd.read()
	fd.close()
	return token

# Initialize the client
client = coscine.Client(token("token.txt"))

# Determine wether the client is up to date
if client.is_outdated():
	print("Please update!")
	exit(0)

# Get a list of projects and print their name and id
projects = client.projects()
for project in projects:
	print("%s : %s" % (project.name, project.id))

# Get a filtered list of projects and print their name and id
projects = client.projects(startDate = "2021-02-02", endDate = "2021-12-24")
for project in projects:
	print("%s : %s" % (project.name, project.id))

# Get a single project
project = client.project("My Project Name")

# Get a single project by filter
try:
	project = client.project(startDate = "2021-02-02")
except coscine.CoscineException:
	print("Duplicate results!")

# Create a project form
form = client.ProjectForm()
for key in form.keys():
	print(key)

form[""]

# Create JSON-LD metadata out of the form and print said metadata
metadata = form.generate()
print(json.dumps(metadata, indent=4))

# Create a project using the aforementioned project form
client.create_project(form)