###############################################################################
# Coscine Python Client
# Copyright (c) 2018-2021 RWTH Aachen University
# Contact: coscine@itc.rwth-aachen.de
# Git: https://git.rwth-aachen.de/coscine/docs/public/coscine-python-client
# Please direct bug reports, feature requests or questions at the URL above
# by opening an issue.
###############################################################################
# Coscine is an open source project at RWTH Aachen University for
# the management of research data.
# Visit https://coscine.de for more information.
###############################################################################

###############################################################################
# ATTENTION!!!
# This is a test script. Its purpose is to determine wether all workflows
# function correctly i.e. after an update to the Coscine API.
# Use a test account with a test token as a user for this script!
# XXX DO NOT USE IT WITH YOUR MAIN COSCINE ACCOUNT! XXX
# XXX This script will delete all your resources and projects! XXX
###############################################################################

import coscine
import sys

###############################################################################
# Reads a token from a text file
def token(filename):
	fd = open(filename, "r")
	token = fd.read()
	fd.close()
	return token

###############################################################################

client = coscine.Client(token("token.txt"))

###############################################################################
# Delete all projects to get a clean working environment
###############################################################################

print("Preparing test environment...")
print("Deleting all projects with test-user association...")
for p in client.projects():
	print("Deleting Project '" + p.name + "'")
	p.delete()

# Check if all projects got deleted
if not client.projects():
	print("Test Environment created.")
else:
	print("Failed to create test environment (persisting projects)!")
	sys.exit(-1)

###############################################################################
# Create a few projects
###############################################################################

print("Creating Test Projects...")

form = client.ProjectForm()
form["Project Name"] = "Test Project 1"
form["Display Name"] = "Project1"
form["Project Description"] = "Test Project Description"
form["Principal Investigators"] = "Test User"
form["Project Start"] = "2021-08-08"
form["Project End"] = "2022-02-01"
form["Discipline"] = ["Ancient Cultures 101", "History 102"]
form["Participating Organizations"] = ["RWTH Aachen University"]
form["Project Keywords"] = "Keyword1;Keyword2"
project = client.create_project(form)
form.reset()
form["Project Name"] = "Test Project 2"
form["Display Name"] = "Project2"
form["Project Description"] = "Test Project Description"
form["Principal Investigators"] = "Test User"
form["Project Start"] = "2021-08-08"
form["Project End"] = "2022-02-01"
form["Discipline"] = ["Ancient Cultures 101", "History 102"]
form["Participating Organizations"] = ["RWTH Aachen University"]
form["Project Keywords"] = "Keyword1;Keyword2"
project = client.create_project(form)
form.reset()
form["Project Name"] = "Test Project 3"
form["Display Name"] = "Project3"
form["Project Description"] = "Test Project Description"
form["Principal Investigators"] = "Test User"
form["Project Start"] = "2021-08-08"
form["Project End"] = "2022-02-01"
form["Discipline"] = ["Ancient Cultures 101", "History 102"]
form["Participating Organizations"] = ["RWTH Aachen University"]
form["Project Keywords"] = "Keyword1;Keyword2"
project = client.create_project(form)

print("Test projects created. Checking wether they appear in our workspace...")

# Get a list of project names
projects = client.projects()
if len(projects) != 3:
	sys.exit(-1)
names = [p.name for p in projects]
check = ["Project1", "Project2", "Project3"]
for c in check:
	if not c in names:
		print("Project not found!")
		sys.exit(-1)

print("Projects appear in workspace!")

###############################################################################
# Invite a bunch of users
###############################################################################

project = client.project("Project1")

###############################################################################
# Create a few resources
###############################################################################

# Create a resource
project = client.project("Project1")
form = project.ResourceForm()
form["Resource Type"] = "rds"
form["Resource Size"] = "10"
form["Resource Name"] = "TestResource1"
form["Display Name"] = "TestResource"
form["Resource Description"] = "Lengthy description of this resource"
form["Discipline"] = ["Computer Science 409", "Medicine 205"]
form["Resource Keywords"] = "Python Client 0.5.0"
form["License"] = "MIT License"
form["Application Profile"] = "RADAR"
resource = project.create_resource(form)

# Fetch resource
#resource = project.resource("TestResource")
print(resource.name)

# Create resource metadata preset
form = resource.MetadataPresetForm()
print(form)
form["Title"] = "Prest Title"
form["Resource"] = "Image"
print(form)
resource.update_preset(form)

###############################################################################
# Upload and download some files
###############################################################################

metadata = resource.MetadataForm()
metadata["Production Date"] = "2021-01-01"
resource.upload("person1_bacteria_1.jpeg", "Chest X-Ray Pneumonia/person1_bacteria_1.jpeg", metadata)
for p in resource.objects():
	print(p.name)

resource.download()

###############################################################################
# Clean up
###############################################################################

for p in client.projects():
	for r in p.resources():
		print("Deleting resource '" + r.name + "'...")
		r.delete()
	print("Deleting project '" + p.name + "'...")
	p.delete()